@@ -43,7 +43,7 @@ class AzIdToNameMapping(
         :param scope: -
         :param id: -
         :param az_ids: The target AZ IDs for mapping. Defaults to values for 3 zones in us-east-1. Default: ['use1-az2', 'use1-az4', 'use1-az6']
-        :param lambda_code: The lambda function code to use for the custom resource. For most use cases this should be left as the default, but in cases where the custom resource needs to be deployed through something like CloudFormation StackSets you may need to source the lambda function code from S3 or some other location because the CDK cant upload the local code to the correct asset location for the StackSet target accounts. You can use the included ``AccessKeyFunctionCodeCache`` class to cache the lambda function code in S3 and create a cross account access policy to allow the StackSet target accounts to access the code. Default: - default lambda function code
+        :param lambda_code: The lambda function code to use for the custom resource. For most use cases this should be left as the default, but in cases where the custom resource needs to be deployed through something like CloudFormation StackSets you may need to source the lambda function code from S3 or some other location because the CDK cant upload the local code to the correct asset location for the StackSet target accounts. You can use the included ``AzIdToNameMappingFunctionCodeCache`` class to cache the lambda function code in S3 and create a cross account access policy to allow the StackSet target accounts to access the code. Default: - default lambda function code
         :param log_retention: The number of days to retain log events in CloudWatch logs. Defaults to 30 days. Default: logs.RetentionDays.ONE_MONTH
         :param ssm_parameter_prefix: The prefix to use for the SSM parameter names. Defaults to ``/az-mapping/``. Default: '/az-mapping/'
         '''
@@ -781,7 +781,7 @@ class AzIdToNameMappingProps:
         '''The properties of a new AZ ID to name mapping.
 
         :param az_ids: The target AZ IDs for mapping. Defaults to values for 3 zones in us-east-1. Default: ['use1-az2', 'use1-az4', 'use1-az6']
-        :param lambda_code: The lambda function code to use for the custom resource. For most use cases this should be left as the default, but in cases where the custom resource needs to be deployed through something like CloudFormation StackSets you may need to source the lambda function code from S3 or some other location because the CDK cant upload the local code to the correct asset location for the StackSet target accounts. You can use the included ``AccessKeyFunctionCodeCache`` class to cache the lambda function code in S3 and create a cross account access policy to allow the StackSet target accounts to access the code. Default: - default lambda function code
+        :param lambda_code: The lambda function code to use for the custom resource. For most use cases this should be left as the default, but in cases where the custom resource needs to be deployed through something like CloudFormation StackSets you may need to source the lambda function code from S3 or some other location because the CDK cant upload the local code to the correct asset location for the StackSet target accounts. You can use the included ``AzIdToNameMappingFunctionCodeCache`` class to cache the lambda function code in S3 and create a cross account access policy to allow the StackSet target accounts to access the code. Default: - default lambda function code
         :param log_retention: The number of days to retain log events in CloudWatch logs. Defaults to 30 days. Default: logs.RetentionDays.ONE_MONTH
         :param ssm_parameter_prefix: The prefix to use for the SSM parameter names. Defaults to ``/az-mapping/``. Default: '/az-mapping/'
         '''
@@ -823,7 +823,7 @@ class AzIdToNameMappingProps:
         the CDK cant upload the local code to the correct asset location
         for the StackSet target accounts.
 
-        You can use the included ``AccessKeyFunctionCodeCache`` class to
+        You can use the included ``AzIdToNameMappingFunctionCodeCache`` class to
         cache the lambda function code in S3 and create a cross
         account access policy to allow the StackSet target accounts
         to access the code.
